Commit: 50af4d208d7d2f3cbc789e91e54d87adf37590fb
Author: Campbell Barton
Date:   Fri Oct 3 08:09:00 2014 +0200
Branches: master
https://developer.blender.org/rB50af4d208d7d2f3cbc789e91e54d87adf37590fb

Cleanup: spelling, ws

===================================================================

M       source/blender/editors/io/io_collada.c
M       source/blender/editors/mesh/editmesh_loopcut.c
M       source/blender/editors/transform/transform.c
M       source/blender/freestyle/intern/view_map/FEdgeXDetector.cpp
M       source/blender/freestyle/intern/view_map/FEdgeXDetector.h
M       source/blender/freestyle/intern/winged_edge/WXEdge.h

===================================================================

diff --git a/source/blender/editors/io/io_collada.c 
b/source/blender/editors/io/io_collada.c
index d81a8d7..bbf4447 100644
--- a/source/blender/editors/io/io_collada.c
+++ b/source/blender/editors/io/io_collada.c
@@ -171,10 +171,10 @@ static int wm_collada_export_exec(bContext *C, wmOperator 
*op)
                export_transformation_type,
                open_sim);
 
-       if(export_count == 0) {
+       if (export_count == 0) {
                BKE_report(op->reports, RPT_WARNING, "Export file is empty");
                return OPERATOR_CANCELLED;
-               }
+       }
        else {
                char buff[100];
                sprintf(buff, "Exported %d Objects", export_count);
diff --git a/source/blender/editors/mesh/editmesh_loopcut.c 
b/source/blender/editors/mesh/editmesh_loopcut.c
index 12be32b..b5508ef 100644
--- a/source/blender/editors/mesh/editmesh_loopcut.c
+++ b/source/blender/editors/mesh/editmesh_loopcut.c
@@ -362,9 +362,9 @@ static void edgering_select(RingSelOpData *lcd)
        }
 
        BMW_init(&walker, em->bm, BMW_EDGERING,
-                        BMW_MASK_NOP, BMW_MASK_NOP, BMW_MASK_NOP,
-                        BMW_FLAG_TEST_HIDDEN,
-                        BMW_NIL_LAY);
+                BMW_MASK_NOP, BMW_MASK_NOP, BMW_MASK_NOP,
+                BMW_FLAG_TEST_HIDDEN,
+                BMW_NIL_LAY);
 
        for (eed = BMW_begin(&walker, eed_start); eed; eed = BMW_step(&walker)) 
{
                BM_edge_select_set(em->bm, eed, true);
diff --git a/source/blender/editors/transform/transform.c 
b/source/blender/editors/transform/transform.c
index 8378c9f..c7ff9f0 100644
--- a/source/blender/editors/transform/transform.c
+++ b/source/blender/editors/transform/transform.c
@@ -4068,7 +4068,7 @@ static void initTranslation(TransInfo *t)
                /* this space uses time translate */
                BKE_report(t->reports, RPT_ERROR, 
                           "Use 'Time_Translate' transform mode instead of 
'Translation' mode "
-                                  "for translating keyframes in Dope Sheet 
Editor");
+                          "for translating keyframes in Dope Sheet Editor");
                t->state = TRANS_CANCEL;
        }
 
diff --git a/source/blender/freestyle/intern/view_map/FEdgeXDetector.h 
b/source/blender/freestyle/intern/view_map/FEdgeXDetector.h
index 8adf685..8170fc5 100644
--- a/source/blender/freestyle/intern/view_map/FEdgeXDetector.h
+++ b/source/blender/freestyle/intern/view_map/FEdgeXDetector.h
@@ -57,7 +57,7 @@ public:
        {
                _pProgressBar = NULL;
                _pRenderMonitor = NULL;
-               _computeViewIndependant = true;
+               _computeViewIndependent = true;
                _bbox_diagonal = 1.0;
                _meanEdgeSize = 0;
                _computeRidgesAndValleys = true;
@@ -213,7 +213,7 @@ protected:
        Vec3r _Viewpoint;
        real _bbox_diagonal; // diagonal of the current processed shape bbox
        //oldtmp values
-       bool _computeViewIndependant;
+       bool _computeViewIndependent;
        real _meanK1;
        real _meanKr;
        real _minK1;
diff --git a/source/blender/freestyle/intern/winged_edge/WXEdge.h 
b/source/blender/freestyle/intern/winged_edge/WXEdge.h
index ce97493..3c9ec7a 100644
--- a/source/blender/freestyle/intern/winged_edge/WXEdge.h
+++ b/source/blender/freestyle/intern/winged_edge/WXEdge.h
@@ -718,18 +718,18 @@ public:
        typedef WXShape type_name;
 
 protected:
-       bool _computeViewIndependant; // flag to indicate whether the view 
independant stuff must be computed or not
+       bool _computeViewIndependent; // flag to indicate whether the view 
independent stuff must be computed or not
 
 public:
        inline WXShape() : WShape()
        {
-               _computeViewIndependant = true;
+               _computeViewIndependent = true;
        }
 
        /*! copy constructor */
        inline WXShape(WXShape& iBrother) : WShape(iBrother)
        {
-               _computeViewIndependant = iBrother._computeViewIndependant;
+               _computeViewIndependent = iBrother._computeViewIndependent;
        }
 
        virtual WShape *duplicate()
@@ -740,14 +740,14 @@ public:
 
        virtual ~WXShape() {}
 
-       inline bool getComputeViewIndependantFlag() const
+       inline bool getComputeViewIndependentFlag() const
        {
-               return _computeViewIndependant;
+               return _computeViewIndependent;
        }
 
-       inline void setComputeViewIndependantFlag(bool iFlag)
+       inline void setComputeViewIndependentFlag(bool iFlag)
        {
-               _computeViewIndependant = iFlag;
+               _computeViewIndependent = iFlag;
        }
 
        /*! designed to build a specialized WFace for use in MakeFace */

_______________________________________________
Bf-blender-cvs mailing list
[email protected]
http://lists.blender.org/mailman/listinfo/bf-blender-cvs

Reply via email to
diff --git a/source/blender/freestyle/intern/view_map/FEdgeXDetector.cpp 
b/source/blender/freestyle/intern/view_map/FEdgeXDetector.cpp
index 9c9cd88..a5e526f 100644
--- a/source/blender/freestyle/intern/view_map/FEdgeXDetector.cpp
+++ b/source/blender/freestyle/intern/view_map/FEdgeXDetector.cpp
@@ -63,14 +63,14 @@ void FEdgeXDetector::processShapes(WingedEdge& we)
                                WXFace *wxf = dynamic_cast<WXFace*>(*wf);
                                wxf->Clear();
                        }
-                       _computeViewIndependant = true;
+                       _computeViewIndependent = true;
                }
-               else if (!(wxs)->getComputeViewIndependantFlag()) {
+               else if (!(wxs)->getComputeViewIndependentFlag()) {
                        wxs->Reset();
-                       _computeViewIndependant = false;
+                       _computeViewIndependent = false;
                }
                else {
-                       _computeViewIndependant = true;
+                       _computeViewIndependent = true;
                }
                preProcessShape(wxs);
                if (progressBarDisplay)
@@ -97,8 +97,8 @@ void FEdgeXDetector::processShapes(WingedEdge& we)
                if (progressBarDisplay)
                        _pProgressBar->setProgress(_pProgressBar->getProgress() 
+ 1);
 
-               wxs->setComputeViewIndependantFlag(false);
-               _computeViewIndependant = false;
+               wxs->setComputeViewIndependentFlag(false);
+               _computeViewIndependent = false;
                _changes = false;
 
                // reset user data
@@ -187,8 +187,8 @@ void FEdgeXDetector::computeCurvatures(WXVertex *vertex)
        CurvatureInfo *C;
        float radius = _sphereRadius * _meanEdgeSize; 
 
-       // view independant stuff
-       if (_computeViewIndependant) {
+       // view independent stuff
+       if (_computeViewIndependent) {
                C = new CurvatureInfo();
                vertex->setCurvatures(C);
                OGF::NormalCycle ncycle;
@@ -333,7 +333,7 @@ void FEdgeXDetector::ProcessSilhouetteEdge(WXEdge *iEdge)
 /////////
 void FEdgeXDetector::processBorderShape(WXShape *iWShape)
 {
-       if (!_computeViewIndependant)
+       if (!_computeViewIndependent)
                return;
        // Make a pass on the edges to detect the BORDER
        vector<WEdge*>::iterator we, weend;
@@ -358,7 +358,7 @@ void FEdgeXDetector::ProcessBorderEdge(WXEdge *iEdge)
 /////////
 void FEdgeXDetector::processCreaseShape(WXShape *iWShape)
 {
-       if (!_computeViewIndependant)
+       if (!_computeViewIndependent)
                return;
 
        // Make a pass on the edges to detect the CREASE 
@@ -390,7 +390,7 @@ void FEdgeXDetector::processRidgesAndValleysShape(WXShape 
*iWShape)
        // Don't forget to add the built layer to the face at the end of the 
ProcessFace:
        //iFace->AddSmoothLayer(faceLayer);
 
-       if (!_computeViewIndependant)
+       if (!_computeViewIndependent)
                return;
 
        // Here the curvatures must already have been computed
@@ -684,7 +684,7 @@ void 
FEdgeXDetector::postProcessSuggestiveContourFace(WXFace *iFace)
 ////////////////////
 void FEdgeXDetector::processMaterialBoundaryShape(WXShape *iWShape)
 {
-       if (!_computeViewIndependant)
+       if (!_computeViewIndependent)
                return;
        // Make a pass on the edges to detect material boundaries
        vector<WEdge*>::iterator we, weend;